@@ -46,7 +46,10 @@ class Synapse(ABC):
             return self.init_error
 
         self.logger.info(self.request_type)
-        self.logger.info(self.request)
+        # Request type test has credentials in it, we dont want to log.
+        # TODO: find ways to just log non-sensitive info.
+        if self.request_type is not RequestType.TEST:
+            self.logger.info(self.request)
         response = None
         try:
             if self.request_type == RequestType.TEST:
@@ -163,7 +166,9 @@ class Synapse(ABC):
 
     @property
     def logger(self):
-        return SyncariLogger.get_logger(f"{self.name}")
+        if self.raw_request.syncariId is not None:
+            return SyncariLogger.get_logger(f"{self.raw_request.syncariId}")
+        return SyncariLogger.get_logger("custom_synapse")
 
     @abstractmethod
     def synapse_info(self) -> SynapseInfo:
